@@ -8,8 +8,12 @@ def abs(*paths):
 
 class LoggableDevice(object):
     outputs = None
+
     def __init__(self):
         self.outputs = []
 
     def write(self, s):
-        self.outputs.append(s)
\ No newline at end of file
+        self.outputs.append(s)
+
+    def isatty(self):
+        return False
